Index: src/gpu/GrResourceCache2.h |
diff --git a/src/gpu/GrResourceCache2.h b/src/gpu/GrResourceCache2.h |
index 5aee1add86cc7f055314d5763cb883e912a50e50..d5c418238ba480e9bc3017547b144075520b3b9c 100644 |
--- a/src/gpu/GrResourceCache2.h |
+++ b/src/gpu/GrResourceCache2.h |
@@ -155,7 +155,7 @@ private: |
//// |
void insertResource(GrGpuResource*); |
void removeResource(GrGpuResource*); |
- void notifyPurgable(GrGpuResource*); |
+ void notifyPurgeable(GrGpuResource*); |
void didChangeGpuMemorySize(const GrGpuResource*, size_t oldSize); |
bool didSetContentKey(GrGpuResource*); |
void willRemoveScratchKey(const GrGpuResource*); |
@@ -230,7 +230,7 @@ private: |
// prevents recursive purging |
bool fPurging; |
- bool fNewlyPurgableResourceWhilePurging; |
+ bool fNewlyPurgeableResourceWhilePurging; |
PFOverBudgetCB fOverBudgetCB; |
void* fOverBudgetData; |
@@ -254,9 +254,9 @@ private: |
void removeResource(GrGpuResource* resource) { fCache->removeResource(resource); } |
/** |
* Called by GrGpuResources when they detects that they are newly purgable. |
*/ |
- void notifyPurgable(GrGpuResource* resource) { fCache->notifyPurgable(resource); } |
+ void notifyPurgeable(GrGpuResource* resource) { fCache->notifyPurgeable(resource); } |
/** |
* Called by GrGpuResources when their sizes change. |
@@ -254,9 +254,9 @@ private: |
void removeResource(GrGpuResource* resource) { fCache->removeResource(resource); } |
/** |
- * Called by GrGpuResources when they detects that they are newly purgable. |
+ * Called by GrGpuResources when they detects that they are newly purgeable. |
*/ |